@@ -868,7 +868,7 @@ gdl_dock_item_add (GtkContainer *container,
     g_return_if_fail (GDL_IS_DOCK_ITEM (container));
 
     item = GDL_DOCK_ITEM (container);
-    if (GDL_IS_DOCK_OBJECT (widget)) {
+    if (GDL_IS_DOCK_ITEM (widget)) {
         g_warning (_("You can't add a dock object (%p of type %s) inside a %s. "
                      "Use a GdlDock or some other compound dock object."),
                    widget, G_OBJECT_TYPE_NAME (widget), G_OBJECT_TYPE_NAME (item));
@@ -918,7 +918,7 @@ gdl_dock_item_remove (GtkContainer *container,
     item->priv->child = NULL;
 
     if (was_visible)
-        gtk_widget_queue_resize (GTK_WIDGET (container));
+        gtk_widget_hide (GTK_WIDGET (container));
 }
 
 static void
@@ -958,8 +958,6 @@ gdl_dock_item_set_focus_child (GtkContainer *container,
     if (GTK_CONTAINER_CLASS (gdl_dock_item_parent_class)->set_focus_child) {
         (* GTK_CONTAINER_CLASS (gdl_dock_item_parent_class)->set_focus_child) (container, child);
     }
-
-    gdl_dock_item_showhide_grip (GDL_DOCK_ITEM (container));
 }
 
 static void
@@ -1776,7 +1774,7 @@ gdl_dock_item_drag_end (GdlDockItem *item,
 {
     if (item->priv->in_drag) {
         /* Release pointer & keyboard. */
-        gtk_grab_remove (gtk_grab_get_current ());
+        gtk_grab_remove (GTK_WIDGET (item));
         g_signal_emit (item, gdl_dock_item_signals [DOCK_DRAG_END], 0, cancel);
         gtk_widget_grab_focus (GTK_WIDGET (item));
 
@@ -1868,12 +1866,14 @@ gdl_dock_item_showhide_grip (GdlDockItem *item)
 {
     gdl_dock_item_detach_menu (GTK_WIDGET (item), NULL);
 
-    if (item->priv->grip) {
-        if (GDL_DOCK_ITEM_GRIP_SHOWN (item) &&
-            GDL_DOCK_ITEM_NOT_LOCKED(item))
+    if (item->priv->grip && GDL_DOCK_ITEM_NOT_LOCKED(item) &&
+        GDL_DOCK_ITEM_HAS_GRIP(item)) {
+
+        if (item->priv->grip_shown) {
             gdl_dock_item_grip_show_handle (GDL_DOCK_ITEM_GRIP (item->priv->grip));
-        else
+        } else {
             gdl_dock_item_grip_hide_handle (GDL_DOCK_ITEM_GRIP (item->priv->grip));
+        }
     }
 }
 
@@ -2255,7 +2255,6 @@ gdl_dock_item_hide_grip (GdlDockItem *item)
         item->priv->grip_shown = FALSE;
         gdl_dock_item_showhide_grip (item);
     };
-    g_warning ("Grips always show unless GDL_DOCK_ITEM_BEH_NO_GRIP is set\n" );
 }
 
 /**
